@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+"""HTTP Adapter with timeout for Session"""
 
 from requests.adapters import HTTPAdapter
 
@@ -7,6 +7,7 @@ DEFAULT_TIMEOUT = 5
 
 
 class TimeoutHTTPAdapter(HTTPAdapter):
+    """Timeout HTTP Adapter"""
     def __init__(self, *args, **kwargs):
         self.timeout = DEFAULT_TIMEOUT
         if "timeout" in kwargs:
