@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+"""Environment dataclass"""
 
 from dataclasses import dataclass
 from typing import Optional, List
@@ -7,6 +7,7 @@ from typing import Optional, List
 
 @dataclass
 class Environment:
+    """Environment model"""
     name: str
     id: str
     production: bool
