@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+"""Matcher dataclass"""
 
 from dataclasses import dataclass
 from typing import List, Optional
@@ -10,6 +10,7 @@ from .between import Between
 
 @dataclass
 class Matcher:
+    """Split Definition's Rule's Condition's Matcher model"""
     matcher_type: str
     string: Optional[str] = None
     negate: Optional[bool] = None
