@@ -1,18 +1,19 @@
 # -*- coding: utf-8 -*-
-
+"""Split Definition dataclass"""
 
 from dataclasses import dataclass
 from typing import Optional, List
 
-from .treatment import Treatment
-from .default_rule import DefaultRule
-from .environment import Environment
-from .traffic_type import TrafficType
 from .rule import Rule
+from .treatment import Treatment
+from .environment import Environment
+from .default_rule import DefaultRule
+from .traffic_type import TrafficType
 
 
 @dataclass
 class SplitDefinition:
+    """Split Definition model"""
     treatments: List[Treatment]
     defaultTreatment: str
     defaultRule: List[DefaultRule]
