@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+"""Treatment dataclass"""
 
 from dataclasses import dataclass
 from typing import Optional, List
@@ -7,6 +7,7 @@ from typing import Optional, List
 
 @dataclass
 class Treatment:
+    """Split definition's Treatment model"""
     name: str
     description: Optional[str] = None
     configurations: Optional[str] = None
