@@ -1,4 +1,5 @@
 # -*- coding: utf-8 -*-
+"""Environment Schema with exclude"""
 
 
 from marshmallow import Schema, fields, post_dump, post_load, EXCLUDE
@@ -7,6 +8,10 @@ from splitiorequests.models.environments.environment import Environment
 
 
 class EnvironmentSchemaExclude(Schema):
+    """Environment schema class
+
+    Ignores and exclude unknown fields
+    """
     class Meta:
         ordered = True
         unknown = EXCLUDE
@@ -29,10 +34,12 @@ class EnvironmentSchemaExclude(Schema):
 
     @post_load
     def load_environment(self, data, **kwargs):
+        """Generates and returns Environment object"""
         return Environment(**data)
 
     @post_dump
     def clean_empty(self, data, **kwargs):
+        """Converts Schema object into dictionary and removes empty fields"""
         new_data = data.copy()
         for field_key in (key for key in data if data[key] is None):
             del new_data[field_key]
