@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+"""Split Definition's Rule's Bucket Schema with exclude"""
 
 from marshmallow import Schema, fields, post_load, post_dump, EXCLUDE
 
@@ -7,6 +7,10 @@ from splitiorequests.models.splits.bucket import Bucket
 
 
 class BucketSchemaExclude(Schema):
+    """Bucket schema class
+
+    Ignores and exclude unknown fields
+    """
     class Meta:
         unknown = EXCLUDE
         ordered = True
@@ -16,8 +20,10 @@ class BucketSchemaExclude(Schema):
 
     @post_load
     def load_bucket(self, data, **kwargs):
+        """Generates and returns Bucket object"""
         return Bucket(**data)
 
     @post_dump
     def convert_to_dict(self, data, **kwargs):
+        """Converts Schema object into dictionary"""
         return dict(data)
