@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+"""Split Definition's Rule's Condition's Matcher's Depends Schema with exclude"""
 
 from marshmallow import Schema, fields, post_load, post_dump, EXCLUDE
 
@@ -7,6 +7,10 @@ from splitiorequests.models.splits.depends import Depends
 
 
 class DependsSchemaExclude(Schema):
+    """Depends schema class
+
+    Ignores and exclude unknown fields
+    """
     class Meta:
         unknown = EXCLUDE
         ordered = True
@@ -16,8 +20,10 @@ class DependsSchemaExclude(Schema):
 
     @post_load
     def load_depends(self, data, **kwargs):
+        """Generates and returns Depends object"""
         return Depends(**data)
 
     @post_dump
     def convert_to_dict(self, data, **kwargs):
+        """Converts Schema object into dictionary"""
         return dict(data)
