@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+"""Split Definition's Environment Schema with exclude"""
 
 from marshmallow import Schema, fields, post_load, post_dump, EXCLUDE
 
@@ -7,6 +7,10 @@ from splitiorequests.models.splits.environment import Environment
 
 
 class EnvironmentSchemaExclude(Schema):
+    """Environment schema class
+
+    Ignores and exclude unknown fields
+    """
     class Meta:
         unknown = EXCLUDE
         ordered = True
@@ -16,8 +20,10 @@ class EnvironmentSchemaExclude(Schema):
 
     @post_load
     def load_environment(self, data, **kwargs):
+        """Generates and returns Environment object"""
         return Environment(**data)
 
     @post_dump
     def convert_to_dict(self, data, **kwargs):
+        """Converts Schema object into dictionary"""
         return dict(data)
