@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+"""Split Definition's Rule's Matcher Schema"""
 
 from marshmallow import Schema, fields, post_dump, post_load
 
@@ -9,6 +9,10 @@ from splitiorequests.models.splits.matcher import Matcher
 
 
 class MatcherSchema(Schema):
+    """Matcher schema class
+
+    Raises exception when unknown field is detected
+    """
     class Meta:
         ordered = True
 
@@ -25,10 +29,12 @@ class MatcherSchema(Schema):
 
     @post_load
     def load_matcher(self, data, **kwargs):
+        """Generates and returns Matcher object"""
         return Matcher(**data)
 
     @post_dump
     def clean_empty(self, data, **kwargs):
+        """Converts Schema object into dictionary and removes empty fields"""
         new_data = data.copy()
         for field_key in (key for key in data if data[key] is None):
             del new_data[field_key]
