@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+"""Split Definition's Rule's Condition's Matcher Schema with exclude"""
 
 from marshmallow import Schema, fields, post_dump, post_load, EXCLUDE
 
@@ -9,6 +9,10 @@ from splitiorequests.models.splits.matcher import Matcher
 
 
 class MatcherSchemaExclude(Schema):
+    """Matcher schema class
+
+    Ignores and exclude unknown fields
+    """
     class Meta:
         unknown = EXCLUDE
         ordered = True
@@ -26,10 +30,12 @@ class MatcherSchemaExclude(Schema):
 
     @post_load
     def load_matcher(self, data, **kwargs):
+        """Generates and returns Matcher object"""
         return Matcher(**data)
 
     @post_dump
     def clean_empty(self, data, **kwargs):
+        """Converts Schema object into dictionary and removes empty fields"""
         new_data = data.copy()
         for field_key in (key for key in data if data[key] is None):
             del new_data[field_key]
