@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+"""Split Definition's Rule Schema"""
 
 from marshmallow import Schema, fields, post_load, post_dump
 
@@ -9,6 +9,10 @@ from splitiorequests.models.splits.rule import Rule
 
 
 class RuleSchema(Schema):
+    """Rule schema class
+
+    Raises exception when unknown field is detected
+    """
     class Meta:
         ordered = True
 
@@ -17,8 +21,10 @@ class RuleSchema(Schema):
 
     @post_load
     def load_rule(self, data, **kwargs):
+        """Generates and returns Rule object"""
         return Rule(**data)
 
     @post_dump
     def convert_to_dict(self, data, **kwargs):
+        """Converts Schema object into dictionary"""
         return dict(data)
