@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+"""Traffic Type Schema"""
 
 from marshmallow import Schema, fields, post_load, post_dump
 
@@ -7,6 +7,10 @@ from splitiorequests.models.splits.traffic_type import TrafficType
 
 
 class TrafficTypeSchema(Schema):
+    """Traffic Type schema class
+
+    Raises exception when unknown field is detected
+    """
     class Meta:
         ordered = True
 
@@ -15,8 +19,10 @@ class TrafficTypeSchema(Schema):
 
     @post_load
     def load_traffic_type(self, data, **kwargs):
+        """Generates and returns TrafficType object"""
         return TrafficType(**data)
 
     @post_dump
     def convert_to_dict(self, data, **kwargs):
+        """Converts Schema object into dictionary"""
         return dict(data)
