@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+"""Traffic Type Schema with exclude"""
 
 from marshmallow import Schema, fields, post_load, post_dump, EXCLUDE
 
@@ -7,6 +7,10 @@ from splitiorequests.models.splits.traffic_type import TrafficType
 
 
 class TrafficTypeSchemaExclude(Schema):
+    """TrafficType schema class
+
+    Ignores and exclude unknown fields
+    """
     class Meta:
         unknown = EXCLUDE
         ordered = True
@@ -16,8 +20,10 @@ class TrafficTypeSchemaExclude(Schema):
 
     @post_load
     def load_traffic_type(self, data, **kwargs):
+        """Generates and returns TrafficType object"""
         return TrafficType(**data)
 
     @post_dump
     def convert_to_dict(self, data, **kwargs):
+        """Converts Schema object into dictionary"""
         return dict(data)
