@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-
+"""Split Definition's Treatment Schema"""
 
 from marshmallow import Schema, fields, post_dump, post_load
 
@@ -7,6 +7,10 @@ from splitiorequests.models.splits.treatment import Treatment
 
 
 class TreatmentSchema(Schema):
+    """Treatment schema class
+
+    Raises exception when unknown field is detected
+    """
     class Meta:
         ordered = True
 
@@ -18,10 +22,12 @@ class TreatmentSchema(Schema):
 
     @post_load
     def load_treatment(self, data, **kwargs):
+        """Generates and returns Treatment object"""
         return Treatment(**data)
 
     @post_dump
     def clean_empty(self, data, **kwargs):
+        """Converts Schema object into dictionary and removes empty fields"""
         new_data = data.copy()
         for field_key in (key for key in data if data[key] is None):
             del new_data[field_key]
